@@ -1,6 +1,7 @@
 from automata_tools.Automata import Automata
 from automata_tools.BuildAutomata import BuildAutomata
-from automata_tools.DFAFromNFA import DFAFromNFA
+from automata_tools.NFAtoDFA import NFAtoDFA
+from automata_tools.DFAtoMinimizedDFA import DFAtoMinimizedDFA
 from automata_tools.WFA import WFA
 
 from automata_tools.utils import drawGraph, isInstalled, get_word_to_index
